#
# spec file for package microos-tools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?_distconfdir: %global _distconfdir %{_prefix}%{_sysconfdir}}

Name:           microos-tools
Version:        2.21+git5
Release:        1.1
Summary:        Files and Scripts for openSUSE MicroOS
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://github.com/openSUSE/microos-tools
Source:         microos-tools-%{version}.tar.xz
Source1:        tmp.mount
Source2:        microos-tmp.conf
Source99:       microos-tools-rpmlintrc
BuildRequires:  automake
BuildRequires:  distribution-release
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dracut)
BuildRequires:  pkgconfig(rpm)
BuildRequires:  pkgconfig(systemd)
Requires:       read-only-root-fs

%description
Files, scripts and directories for openSUSE MicroOS.

%package -n microos-devel-tools
Summary:        Tools to develop MicroOS

%description -n microos-devel-tools
This package contains tools to make developing of MicroOS easier.

%prep
%autosetup -p1

%build
./autogen.sh
%configure
%make_build

%install
%make_install
%if 0%{?suse_version} <= 1500
install -m 0644 %{SOURCE1} %{buildroot}/%{_unitdir}/
install -m 0644 %{SOURCE2} %{buildroot}/%{_tmpfilesdir}
%endif

%pre
%service_add_pre setup-systemd-proxy-env.service setup-systemd-proxy-env.path printenv.service

%post
%{regenerate_initrd_post}
%service_add_post setup-systemd-proxy-env.service setup-systemd-proxy-env.path printenv.service

%preun
%service_del_preun setup-systemd-proxy-env.service setup-systemd-proxy-env.path printenv.service

%postun
%{regenerate_initrd_post}
%service_del_postun setup-systemd-proxy-env.service setup-systemd-proxy-env.path printenv.service

%posttrans
%{regenerate_initrd_posttrans}

%pre -n microos-devel-tools
%service_add_pre microos-ro.service

%post -n microos-devel-tools
%service_add_post microos-ro.service

%preun -n microos-devel-tools
%service_del_preun microos-ro.service

%postun -n microos-devel-tools
%service_del_postun microos-ro.service

%files
%license COPYING
%dir %{_sysconfdir}/selinux
%config %{_sysconfdir}/selinux/fixfiles_exclude_dirs
%{_unitdir}/printenv.service
%{_unitdir}/setup-systemd-proxy-env.path
%{_unitdir}/setup-systemd-proxy-env.service
%dir %{_unitdir}/salt-minion.service.d
%{_unitdir}/salt-minion.service.d/TMPDIR.conf
%{_tmpfilesdir}/salt-minion-tmpdir.conf
%if %{?suse_version} <= 1500
%dir %{_distconfdir}
%endif
%dir %{_distconfdir}/tukit.conf.d
%{_distconfdir}/tukit.conf.d/salt-tukit.conf
%{_sbindir}/setup-systemd-proxy-env
%dir %{_prefix}/lib/dracut
%dir %{_prefix}/lib/dracut/modules.d
%{_prefix}/lib/dracut/modules.d/98selinux-microos
%{_systemdgeneratordir}/selinux-autorelabel-generator
%if 0%{?suse_version} <= 1500
%{_unitdir}/tmp.mount
%{_tmpfilesdir}/microos-tmp.conf
%endif

%files -n microos-devel-tools
%{_unitdir}/microos-ro.service
%{_sbindir}/microos-ro
%{_sbindir}/microos-rw
%{_sbindir}/rpm-sortbysize
%{_sbindir}/rpmorphan
%{_sbindir}/sysext-add-debug

%changelog
* Thu Oct 12 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 2.21+git5:
  * 98selinux-microos: Set mount propagation properly
  * 98selinux-microos: Convert tabs to spaces
  * 98selinux-microos: Don't include setenforce unnecessarily
  * Add spec file
  * systemd-proxy-env: fix typos in setup-systemd-proxy-env
- Use the .spec file from the repo
* Thu Apr 20 2023 Fabian Vogt <fvogt@suse.com>
- Switch to obs_scm
- Call autogen.sh so that it actually builds
- Update to version 2.21+git0:
  * Release version 2.21
  * 98selinux-microos: Work around overlayfs bug (bsc#1210690)
  * 98selinux-microos: Create .relabelled marker before relabelling
* Thu Apr 13 2023 kukuk@suse.com
- Update to version 2.20+git20230413.2a43cdb:
  * Drop extra sysctl file for coredumps (boo#1091684)
* Tue Apr  4 2023 Ludwig Nussel <lnussel@suse.de>
- remove conflict with systemd-coredump (boo#1091684). There is no actual
  conflict. It actually works fine to install systemd-coredump in addition.
* Thu Mar 16 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 2.20:
  - 98selinux-microos: don't load the policy to label the system
* Tue Mar 14 2023 Fabian Vogt <fvogt@suse.com>
- Update URL
- Update to version 2.19:
  - configure.ac: Run autoupdate to fix some deprecation warnings
  - Clean up selinux-autorelabel-generator and make it compatible with systemd 253
* Thu Jan 19 2023 Ignaz Forster <iforster@suse.com>
- Update to version 2.18:
  - Add TMPDIR to tukit binddirs for Salt
    [bsc#1211356] [bsc#1205011]
  - 98selinux-microos: Add chroot as dependency
  - Fix spelling error in warning
* Fri Sep 16 2022 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.17:
  - selinux-autorelabel-generator: Don't cross partition boundaries
  for /.snapshots when relabeling [issue#11]
* Mon Sep  5 2022 Fabian Vogt <fvogt@suse.com>
- Update to version 2.16:
  - 98selinux-microos: Make the btrfs subvolume writable temporarily [boo#1202395]
* Wed Aug 31 2022 Fabian Vogt <fvogt@suse.com>
- Update to version 2.15
  - 98selinux-microos: Add grep as dependency
* Tue Aug 30 2022 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.14
  - Fix Makefile to install sysext-add-debug
* Tue Aug 30 2022 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.13
  - 98selinux-microos: Don't rely on selinux=1 [bsc#1202449]
  - Add sysext-add-debug
  - Make sure /var/lib/overlay exists before relabeling
* Thu Sep  9 2021 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.12
  - Remove special MicroOS firstboot script
  - Remove locale-check, replaced by another aaa_base implementation
* Wed Jun 16 2021 Ignaz Forster <iforster@suse.com>
- Update to version 2.11
  - Fix unwritable /var / /etc after SELinux relabel [bsc#1186563]
* Mon May 10 2021 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.10
  - Fixes and improvements for SELinux support
  - Add devel tools
- Add new subpackage microos-devel-tools
- Add rpm as build dependency for that subpackage
* Tue Nov 10 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.9
  - Use absolute path for selinuxenabled in systemd generator
* Mon Nov  9 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.8
  - Don't propagate umounts into the real root
  - Use content of .autorelabel only if it exists
* Wed Oct 28 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.7
  - Add workaround if /.autorelabel is used, don't ignore it
- Rename tmp.conf to microos-tmp.conf on SUSE MicroOS
* Thu Oct 22 2020 Thorsten Kukuk <kukuk@suse.com>
- Fix building on SUSE MicroOS
* Wed Oct 21 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.6
  - Don't delete autorelabel file in initrd
* Mon Sep 28 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.5
  - tmp.conf now part of filesystem package for Factory
- Include tmp.conf for SUSE MicroOS
* Tue Aug 18 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.4
  - fixes for autorelabel in initrd
  - Use systemds tmpfiles.d/tmp.conf to relabel /tmp and cleanup
    /tmp after 10 days and /var/tmp after 30 days
* Tue Aug 18 2020 Thorsten Kukuk <kukuk@suse.com>
- Don't install tmp.mount.d/selinux.conf on Factory [bsc#1175379]
* Fri Aug 14 2020 Thorsten Kukuk <kukuk@suse.com>
- Add tmp.mount for SUSE MicroOS 5.0 [jsc#SMO-2]
* Wed Aug 12 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.3
  - SELinux support [jsc#SMO-15]
  - overwrite tmp.mount options with SELinux label for /tmp
  - Add generator to label mount points if required
  - Add dracut module to relabel core system if required
  - Add locale-check to reset locale to system default if the one
    set by SSH does not exist [bsc#1156175]
  - Set TMPDIR for salt to not use /tmp (preparation for noexec)
* Thu Jul 30 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.2
  - tmpfs support got moved to systemd
* Fri Jun  5 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.1
  - Provide support to use tmpfs for /tmp
* Sun May 10 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.0
  - use autoconf tools to support libexecdir
* Fri Feb 14 2020 kukuk@suse.de
- Update to version 1.0+git20200214.c7654a7:
  * Remove btrfsQuota, snapper list provides now the same informations
  * Adjust README.md
* Mon Aug 12 2019 kukuk@suse.de
- Remove create_autoyast_profile from sources
* Mon Aug 12 2019 kukuk@suse.de
- Update to version 1.0+git20190812.97ca0ee:
  * Add create_autoyast_profile to caasp section for reference
* Tue Jun 11 2019 kukuk@suse.de
- Update to version 1.0+git20190611.6211f74:
  * Rename 51-corefiles.conf to 30-corefiles.conf, so that an user
    can override it by installing telemectrics-client or
    systemd-coredump.
* Wed Feb 27 2019 kukuk@suse.de
- Re-add requires for perl-JSON, required by create_autoyast_profile
* Mon Feb 18 2019 kukuk@suse.de
- Create own standalone microos-tools package
* Mon Feb 18 2019 kukuk@suse.de
- Update to version 1.0+git20190218.9e72dd7:
  * Move SUSE CaaS Platform specific code to CaaSP directory
  * Move core files to /var/tmp, /tmp could be tmpfs
  * Add service to print environment for debugging
* Wed Dec 12 2018 kukuk@suse.de
- Update to version 1.0+git20181212.c28b214:
  * Store manual page uncompressed
* Wed Dec 12 2018 kukuk@suse.de
- Update to version 1.0+git20181212.a821c06:
  * Add manual page for btrfsQuota
  * Fix permissions of btrfsQuota
  * Add btrfsQuota command (from btrfs wiki)
* Fri Dec  7 2018 kukuk@suse.de
- Update to version 1.0+git20181207.2d715d2:
  * Don't configure systemd-timesyncd anymore on the cluster nodes, admin has to use the ntp module, which can meanwhile configure everything.
  * Fix formating of bash script
  * Add service, which watches /etc/sysconfig/proxy and sets the environment variables for systemd services
  * Fix product name
  * Move cloud-init module for caasp into caasp special sub directory
* Wed Sep 26 2018 kukuk@suse.de
- Update to version 1.0+git20180926.e9f5cfe:
  * Overwrite systemd-coredump for core files, as systemd is not
    available in containers.
- Add conflict with systemd-coredump
* Tue Aug 21 2018 kukuk@suse.de
- Update to version 1.0+git20180821.b2af3a9:
  * Start timesyncd service first on cluster nodes.
  * Remove start of container-feeder, does not exist anymore on SLE15
* Sun Jun 17 2018 kukuk@suse.de
- Create /var/adm/netconfig in %%posttrans if still needed after
  upgrade
* Fri Jun 15 2018 kukuk@suse.de
- Update to version 1.0+git20180615.b5e9b2d:
  * Move log file to /var/log, add timestamp
* Fri Jun 15 2018 kukuk@suse.de
- Fix name of migration script
* Fri Jun 15 2018 kukuk@suse.de
- Update to version 1.0+git20180615.6204c42:
  * Save output in logfile
- Fix /var/lock symlink for migration from CaaSP v3 to v4.
* Wed Jun 13 2018 kukuk@suse.de
- Update to version 1.0+git20180613.53ac895:
  * Add migrate-ntp2chrony
- Call migrate-ntp2chrony from posttrans section
* Wed Jun 13 2018 kukuk@suse.de
- Update to version 1.0+git20180613.b7f1fb1:
  * Replace activate.sh call with admin-node-init.service
* Wed Jun 13 2018 kukuk@suse.de
- Update to version 1.0+git20180613.dddd750:
  * Add README.md
* Mon Mar  5 2018 rbrown@suse.com
- Remove Kubic workaround, will now use caasp-container-manifests
* Tue Feb 27 2018 kukuk@suse.de
- Remove read-only root filesystem stuff, was moved to
  read-only-root-fs
- Require read-only-root-fs
* Wed Feb 21 2018 kukuk@suse.de
- Add new hardware and apparmor pattern [bsc#1081620].
* Tue Jan 16 2018 dimstar@opensuse.org
- Drop systemd and dracut BuildRequires: allow to better ordering
  of parallel builds, and neither of the two BRs brings much
  advantage. We just have to own /usr/lib/dracut directories as a
  side effect (which is allowed).
* Tue Jan  9 2018 kukuk@suse.de
- create_autoyast_profile.pl: don't create a swap partition
* Wed Dec 20 2017 kukuk@suse.de
- Version 0.27
  - Adjust that we have only /var
* Sun Dec 17 2017 kukuk@suse.com
- Version 0.26
  - create apparmor overlay only if apparmor is installed
* Sun Sep 24 2017 kukuk@suse.de
- On fix for cc_suse_caasp.py did go lost
* Thu Sep 21 2017 kukuk@suse.de
- Move cc_suse_caasp.py out of tar archive and install with in the
  right python directory
* Tue Sep 12 2017 kukuk@suse.de
- setup-fstab.sys-for-overlayfs: adjust to work with building
  images with kiwi
* Tue Aug 29 2017 kukuk@suse.de
- Add /boot/efi partition to the create_autoyast_profile
  script [bsc#1055795]
* Fri Jun 30 2017 kukuk@suse.de
- Fix problem with wrong permissions of /etc/salt.
* Wed Jun 28 2017 kukuk@suse.de
- Add /etc/salt/minion.d/grains_refresh.conf [bsc#1046212]
* Tue Jun 27 2017 kukuk@suse.de
- Enable admin-note-setup service on admin node via cloud-init
  [bsc#1046161]
* Thu Jun 22 2017 kukuk@suse.de
- suse_caasp cloud-init module: enable salt-minion on admin node
  [bsc#1045350]
* Wed Jun  7 2017 kukuk@suse.de
- Fix syntax of /etc/fstab.sys for overlayfs mount points
* Fri Jun  2 2017 kukuk@suse.de
- suse_caasp cloud-init module: fix order of docker start
* Sat May 27 2017 kukuk@suse.com
- Release version 0.18
- Enable docker and container-feeder on cluster nodes
- Cleanup build requires
* Wed May 17 2017 kukuk@suse.de
- Adjust pattern names [bsc#1039432]
* Tue May  9 2017 kukuk@suse.de
- Add activate.sh for openSUSE Kubic
* Mon Apr 24 2017 kukuk@suse.de
- create_autoyast_profile: use FQDN [bsc#1035665]
* Fri Apr 21 2017 kukuk@suse.de
- Fix order: first write config, afterwards start services
* Fri Apr 21 2017 kukuk@suse.de
- remove not working line from autoyast.xml
- Add COPYING file
* Thu Apr 20 2017 kukuk@suse.de
- Add suse_caasp cloud-init module
- Fix syntax of 01-network.cfg in case we don't disable cloud-init
  network
* Wed Apr 19 2017 kukuk@suse.com
- Add extra /var/lib/docker partition to autoyast profile
* Wed Apr 19 2017 kukuk@suse.de
- Add systemd pre/post install macros
* Tue Apr 18 2017 kukuk@suse.de
- Add apparmor directories for overlayfs
* Tue Apr 18 2017 kukuk@suse.de
- Fix typo
* Tue Apr 18 2017 kukuk@suse.de
- If we do the first boot and there is already a configuration file
  for the network configuration, don't let cloud-init overwrite
  that [bsc#1032497]
* Wed Apr 12 2017 kukuk@suse.de
- Add systemd service to create minion id [bsc#1031623]
* Wed Apr 12 2017 kukuk@suse.de
- Use overlayfs for /var/lib/apparmor
* Sun Apr  2 2017 kukuk@suse.de
- Add ntpd configuration
* Thu Feb 16 2017 kukuk@suse.de
- Remove enabling services workaround
* Mon Feb 13 2017 kukuk@suse.de
- Fix typo in spec file
* Fri Feb 10 2017 kukuk@suse.de
- Add manual page for create_autoyast_profile
- Add script to generate /etc/fstab.sys (mount overlayfs in initrd)
* Wed Feb  1 2017 kukuk@suse.de
- Add workarounds to configure and enable salt-minion in autoyast
  profile
* Sun Jan 29 2017 kukuk@suse.de
- Parse SUSEConnnect -s output for registration information
* Sun Jan 29 2017 kukuk@suse.de
- Disable installer self update in autoyast profile
* Fri Jan 20 2017 kukuk@suse.de
- Adjust for openSUSE support
* Fri Jan 20 2017 kukuk@suse.de
- Replace autoyast profile with script to create it manual
* Sat Jan 14 2017 kukuk@suse.de
- Add autoyast profile caasp.xml
* Sat Jan 14 2017 kukuk@suse.de
- Rename from casp to caasp
* Mon Dec 19 2016 kukuk@suse.de
- Set "hostonly=''" for including overlay kernel module
  [bnc#1016007]
* Wed Dec 14 2016 kukuk@suse.de
- Replace hardcoded device with current root device
* Tue Nov 22 2016 kukuk@suse.de
- Move cloud.cfg into own RPM
* Mon Nov 21 2016 kukuk@suse.de
- Rename "stateless" to "overlay", which fits better from the name
* Tue Nov 15 2016 kukuk@suse.de
- Move systemd presets to own package
* Sun Nov 13 2016 kukuk@suse.de
- Update cloud.cfg
* Sun Nov 13 2016 kukuk@suse.de
- Enable logrotate.timer per default
* Mon Oct 24 2016 kukuk@suse.de
- Initial version with new name
